 /*****************************************************************************
 **  This is part of the SpaceZero program
 **  Copyright (C) 2006-2013  MRevenga
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 3), or
 **  (at your option) any later version, as published by the Free Software 
 **  Foundation.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/

/*************  SpaceZero  M.R.H. 2006-2013 ******************
		Author: MRevenga
		E-mail: mrevenga at users.sourceforge.net
		version 0.86 December 2013
**************************************************************/
#ifndef _FONTS_
#define _FONTS_


#define NUMFONTNAMES 9

char *fontnames[NUMFONTNAMES] =
  { 
    "6x13",
    "lucidasans-8", 
    "-misc-fixed-medium-r-normal--13-120-75-75-c-70-iso8859-1", 
    "-adobe-times-medium-r-normal--14-100-100-100-p-74-iso8859-1",
    "lucida*",
    "*misc-fixed-medium-r*-normal*",
    "*lucida*",
    "*times*",
    "*courier*"};

/*char *fontnames2[NUMFONTNAMES] = */
char *fontnamesMenu[] =
  { 
    "12x24",
    "rk24", 
    "lucidasans-18",
    "9x15",
    "lucidasans-12",
    "-misc-fixed-medium-r-normal--15-120-100-100-c-90-iso8859-1",  
    "*lucida*",
     "*times*",
    "*courier*"};

#endif
